import dotenv from 'dotenv';
import { FisMessage } from "../interface/transport.interface";
import { Adapter } from "./adapter.base";
import { ConnectionState, TransmitterAdapter as TransmitterAdapterInterface, Transport, TransportMessage, TransportService } from '../interface/connector.interface';
import { Subject } from 'rxjs';
import { WrappedMessage } from '../utils/message.ordering';
import ConsoleLogger from '../utils/log.utils';

dotenv.config();
/* This transport manager will be instantiating the necessary transport to deal with tranmission and receiving from different receivers
So how?: */
export class TransmitterAdapter extends Adapter implements TransmitterAdapterInterface {
    private console!: ConsoleLogger

    constructor(adapterId: string, adapterType: Transport, transportService: TransportService) {
        super()
        // logic here
        this.console = new ConsoleLogger(`${adapterType}TransmitterAdapter`, ['adapter'])
        this.connector = transportService
        this.setAdapterProfile(adapterId, adapterType)
    }

    emit(message: WrappedMessage): void {
        // logic here
        this.console.log({ message: `Emitting: ${message.thisMessageID} to ${this.adapterProfile.id}` })
        this.connector.emit({
            id: this.adapterProfile.id,
            transport: this.adapterProfile.transportType,
            target: this.adapterProfile.id, // this should be directed to the channel/client established. Make sure this is right
            payload: message
        } as TransportMessage)
    }

    setAdapterProfile(id: string, adapterType: Transport): void {
        this.adapterProfile = {
            id: id,
            transportType: adapterType
        }
    }

}


